@@ -4,7 +4,7 @@ Contains meaning type.
 .. class Meaning(ParsedObject)
 """
 
-from typing import Union
+import typing
 
 from .base import ParsedObject
 from .definition import Definition
@@ -15,7 +15,7 @@ __all__ = ['Meaning']
 
 class Meaning(ParsedObject):
     """
-    Implements the object of API json response
+    Implements the object of API JSON response
     that consists of meaning data:
 
         * partOfSpeech - part of speech;
@@ -38,13 +38,13 @@ class Meaning(ParsedObject):
         return part_of_speech
 
     @property
-    def definitions(self) -> list[Definition]:
+    def definitions(self) -> typing.List[Definition]:
         """
         :return: list of definitions (parsed objects)
         :rtype: :obj:`list[Definition]`
         """
 
-        definitions_data: list[dict[str, Union[str, list]]] = self._data.get('definitions')
+        definitions_data: typing.List[dict] = self._data.get('definitions')
         definitions = [Definition(definition_data) for definition_data in definitions_data]
 
         return definitions
