@@ -4,8 +4,7 @@ Contains word type (the biggest scale).
 .. class Word(ParsedObject)
 """
 
-from typing import Union
-
+import typing
 from .base import ParsedObject
 from .meaning import Meaning
 from .phonetic import Phonetic
@@ -16,7 +15,7 @@ __all__ = ['Word']
 
 class Word(ParsedObject):
     """
-    Implements the biggest object of the API json response,
+    Implements the biggest object of the API JSON response,
     so it contains all information about word
     that might be retrieved from API
     that structured in different parsed objects.
@@ -29,7 +28,7 @@ class Word(ParsedObject):
     @property
     def word(self) -> str:
         """
-        :return: Word (word name)
+        :return: actually word
         :rtype: :obj:`str`
         """
 
@@ -38,25 +37,25 @@ class Word(ParsedObject):
         return word
 
     @property
-    def phonetics(self) -> list[Phonetic]:
+    def phonetics(self) -> typing.List[Phonetic]:
         """
-        :return: List of phonetics
+        :return: list of phonetics
         :rtype: :obj:`list[Phonetic]`
         """
 
-        phonetics_data: list[dict[str, str]] = self._data.get('phonetics')
+        phonetics_data: typing.List[dict] = self._data.get('phonetics')
         phonetics = [Phonetic(phonetic_data) for phonetic_data in phonetics_data]
 
         return phonetics
 
     @property
-    def meanings(self) -> list[Meaning]:
+    def meanings(self) -> typing.List[Meaning]:
         """
-        :return: List of meanings
+        :return: list of meanings
         :rtype: :obj:`list[Meaning]`
         """
 
-        meanings_data: list[dict[str, Union[str, list]]] = self._data.get('meanings')
+        meanings_data: typing.List[dict] = self._data.get('meanings')
         meanings = [Meaning(meaning_data) for meaning_data in meanings_data]
 
         return meanings
